@@ -4,9 +4,9 @@ from .validators import boolean, exactly_one, integer, positive_integer
 
 class LaunchTemplateSpecification(AWSProperty):
     props = {
-        "LaunchTemplateId": (basestring, False),
-        "LaunchTemplateName": (basestring, False),
-        "Version": (basestring, False),
+        "LaunchTemplateId": (str, False),
+        "LaunchTemplateName": (str, False),
+        "Version": (str, False),
     }
 
     def validate(self):
@@ -20,19 +20,19 @@ class LaunchTemplateSpecification(AWSProperty):
 class ComputeResources(AWSProperty):
 
     props = {
-        "SpotIamFleetRole": (basestring, False),
+        "SpotIamFleetRole": (str, False),
         "MaxvCpus": (positive_integer, True),
-        "SecurityGroupIds": ([basestring], True),
+        "SecurityGroupIds": ([str], True),
         "BidPercentage": (positive_integer, False),
-        "Type": (basestring, True),
-        "Subnets": ([basestring], True),
+        "Type": (str, True),
+        "Subnets": ([str], True),
         "MinvCpus": (positive_integer, True),
         "LaunchTemplate": (LaunchTemplateSpecification, False),
-        "ImageId": (basestring, False),
-        "InstanceRole": (basestring, True),
-        "InstanceTypes": ([basestring], True),
-        "Ec2KeyPair": (basestring, False),
-        "PlacementGroup": (basestring, False),
+        "ImageId": (str, False),
+        "InstanceRole": (str, True),
+        "InstanceTypes": ([str], True),
+        "Ec2KeyPair": (str, False),
+        "PlacementGroup": (str, False),
         "Tags": (dict, False),
         "DesiredvCpus": (positive_integer, False)
     }
@@ -40,9 +40,9 @@ class ComputeResources(AWSProperty):
 
 class Device(AWSProperty):
     props = {
-        'ContainerPath': (basestring, False),
-        'HostPath': (basestring, False),
-        'Permissions': ([basestring], False),
+        'ContainerPath': (str, False),
+        'HostPath': (str, False),
+        'Permissions': ([str], False),
     }
 
 
@@ -56,15 +56,15 @@ class MountPoints(AWSProperty):
 
     props = {
         "ReadOnly": (bool, False),
-        "SourceVolume": (basestring, False),
-        "ContainerPath": (basestring, False)
+        "SourceVolume": (str, False),
+        "ContainerPath": (str, False)
     }
 
 
 class VolumesHost(AWSProperty):
 
     props = {
-        "SourcePath": (basestring, False)
+        "SourcePath": (str, False)
     }
 
 
@@ -72,22 +72,22 @@ class Volumes(AWSProperty):
 
     props = {
         "Host": (VolumesHost, False),
-        "Name": (basestring, False)
+        "Name": (str, False)
     }
 
 
 class Environment(AWSProperty):
 
     props = {
-        "Value": (basestring, False),
-        "Name": (basestring, False)
+        "Value": (str, False),
+        "Name": (str, False)
     }
 
 
 class ResourceRequirement(AWSProperty):
     props = {
-        'Type': (basestring, False),
-        'Value': (basestring, False),
+        'Type': (str, False),
+        'Value': (str, False),
     }
 
 
@@ -96,18 +96,18 @@ class Ulimit(AWSProperty):
     props = {
         "SoftLimit": (positive_integer, True),
         "HardLimit": (positive_integer, True),
-        "Name": (basestring, True)
+        "Name": (str, True)
     }
 
 
 class ContainerProperties(AWSProperty):
 
     props = {
-        'Command': ([basestring], False),
+        'Command': ([str], False),
         'Environment': ([Environment], False),
-        'Image': (basestring, True),
-        'InstanceType': (basestring, False),
-        'JobRoleArn': (basestring, False),
+        'Image': (str, True),
+        'InstanceType': (str, False),
+        'JobRoleArn': (str, False),
         'LinuxParameters': (LinuxParameters, False),
         'Memory': (positive_integer, True),
         'MountPoints': ([MountPoints], False),
@@ -115,7 +115,7 @@ class ContainerProperties(AWSProperty):
         'ReadonlyRootFilesystem': (boolean, False),
         'ResourceRequirements': ([ResourceRequirement], False),
         'Ulimits': ([Ulimit], False),
-        'User': (basestring, False),
+        'User': (str, False),
         'Vcpus': (positive_integer, True),
         'Volumes': ([Volumes], False),
     }
@@ -139,11 +139,11 @@ class JobDefinition(AWSObject):
 
     props = {
         'ContainerProperties': (ContainerProperties, True),
-        'JobDefinitionName': (basestring, False),
+        'JobDefinitionName': (str, False),
         'Parameters': (dict, False),
         'RetryStrategy': (RetryStrategy, False),
         'Timeout': (Timeout, False),
-        'Type': (basestring, True),
+        'Type': (str, True),
     }
 
 
@@ -167,9 +167,9 @@ class ComputeEnvironment(AWSObject):
     resource_type = "AWS::Batch::ComputeEnvironment"
 
     props = {
-        "Type": (basestring, True),
-        "ServiceRole": (basestring, True),
-        "ComputeEnvironmentName": (basestring, False),
+        "Type": (str, True),
+        "ServiceRole": (str, True),
+        "ComputeEnvironmentName": (str, False),
         "ComputeResources": (ComputeResources, True),
         "State": (validate_environment_state, False)
     }
@@ -178,7 +178,7 @@ class ComputeEnvironment(AWSObject):
 class ComputeEnvironmentOrder(AWSProperty):
 
     props = {
-        "ComputeEnvironment": (basestring, True),
+        "ComputeEnvironment": (str, True),
         "Order": (positive_integer, True)
     }
 
@@ -206,5 +206,5 @@ class JobQueue(AWSObject):
         "ComputeEnvironmentOrder": ([ComputeEnvironmentOrder], True),
         "Priority": (positive_integer, True),
         "State": (validate_queue_state, False),
-        "JobQueueName": (basestring, False)
+        "JobQueueName": (str, False)
     }
