@@ -81,7 +81,8 @@ class Alarm(AWSObject):
         'OKActions': ([str], False),
         'Period': (positive_integer, False),
         'Statistic': (str, False),
-        'Threshold': (double, True),
+        'Threshold': (double, False),
+        'ThresholdMetricId': (str, False),
         'TreatMissingData': (str, False),
         'Unit': (str, False),
     }
