@@ -4,29 +4,29 @@
 # See LICENSE file for full license.
 
 from . import AWSObject, AWSProperty
-from .validators import boolean, positive_integer
+from .validators import boolean, double, positive_integer
 
 
 class CognitoIdentityProvider(AWSProperty):
     props = {
-        'ClientId': (str, False),
-        'ProviderName': (str, False),
+        'ClientId': (basestring, False),
+        'ProviderName': (basestring, False),
         'ServerSideTokenCheck': (bool, False),
     }
 
 
 class CognitoStreams(AWSProperty):
     props = {
-        'RoleArn': (str, False),
-        'StreamingStatus': (str, False),
-        'StreamName': (str, False),
+        'RoleArn': (basestring, False),
+        'StreamingStatus': (basestring, False),
+        'StreamName': (basestring, False),
     }
 
 
 class PushSync(AWSProperty):
     props = {
-        'ApplicationArns': ([str], False),
-        'RoleArn': (str, False),
+        'ApplicationArns': ([basestring], False),
+        'RoleArn': (basestring, False),
     }
 
 
@@ -38,21 +38,21 @@ class IdentityPool(AWSObject):
         'CognitoEvents': (dict, False),
         'CognitoIdentityProviders': ([CognitoIdentityProvider], False),
         'CognitoStreams': (CognitoStreams, False),
-        'DeveloperProviderName': (str, False),
-        'IdentityPoolName': (str, False),
-        'OpenIdConnectProviderARNs': ([str], False),
+        'DeveloperProviderName': (basestring, False),
+        'IdentityPoolName': (basestring, False),
+        'OpenIdConnectProviderARNs': ([basestring], False),
         'PushSync': (PushSync, False),
-        'SamlProviderARNs': ([str], False),
+        'SamlProviderARNs': ([basestring], False),
         'SupportedLoginProviders': (dict, False),
     }
 
 
 class MappingRule(AWSProperty):
     props = {
-        'Claim': (str, True),
-        'MatchType': (str, True),
-        'RoleARN': (str, True),
-        'Value': (str, True),
+        'Claim': (basestring, True),
+        'MatchType': (basestring, True),
+        'RoleARN': (basestring, True),
+        'Value': (basestring, True),
     }
 
 
@@ -64,9 +64,9 @@ class RulesConfiguration(AWSProperty):
 
 class RoleMapping(AWSProperty):
     props = {
-        'AmbiguousRoleResolution': (str, False),
+        'AmbiguousRoleResolution': (basestring, False),
         'RulesConfiguration': (RulesConfiguration, False),
-        'Type': (str, True),
+        'Type': (basestring, True),
     }
 
 
@@ -74,7 +74,7 @@ class IdentityPoolRoleAttachment(AWSObject):
     resource_type = "AWS::Cognito::IdentityPoolRoleAttachment"
 
     props = {
-        'IdentityPoolId': (str, True),
+        'IdentityPoolId': (basestring, True),
         'RoleMappings': (dict, False),
         'Roles': (dict, False),
     }
@@ -82,9 +82,9 @@ class IdentityPoolRoleAttachment(AWSObject):
 
 class InviteMessageTemplate(AWSProperty):
     props = {
-        'EmailMessage': (str, False),
-        'EmailSubject': (str, False),
-        'SMSMessage': (str, False),
+        'EmailMessage': (basestring, False),
+        'EmailSubject': (basestring, False),
+        'SMSMessage': (basestring, False),
     }
 
 
@@ -105,24 +105,24 @@ class DeviceConfiguration(AWSProperty):
 
 class EmailConfiguration(AWSProperty):
     props = {
-        'EmailSendingAccount': (str, False),
-        'ReplyToEmailAddress': (str, False),
-        'SourceArn': (str, False),
+        'EmailSendingAccount': (basestring, False),
+        'ReplyToEmailAddress': (basestring, False),
+        'SourceArn': (basestring, False),
     }
 
 
 class LambdaConfig(AWSProperty):
     props = {
-        'CreateAuthChallenge': (str, False),
-        'CustomMessage': (str, False),
-        'DefineAuthChallenge': (str, False),
-        'PostAuthentication': (str, False),
-        'PostConfirmation': (str, False),
-        'PreAuthentication': (str, False),
-        'PreSignUp': (str, False),
-        'PreTokenGeneration': (str, False),
-        'UserMigration': (str, False),
-        'VerifyAuthChallengeResponse': (str, False),
+        'CreateAuthChallenge': (basestring, False),
+        'CustomMessage': (basestring, False),
+        'DefineAuthChallenge': (basestring, False),
+        'PostAuthentication': (basestring, False),
+        'PostConfirmation': (basestring, False),
+        'PreAuthentication': (basestring, False),
+        'PreSignUp': (basestring, False),
+        'PreTokenGeneration': (basestring, False),
+        'UserMigration': (basestring, False),
+        'VerifyAuthChallengeResponse': (basestring, False),
     }
 
 
@@ -145,24 +145,24 @@ class Policies(AWSProperty):
 
 class NumberAttributeConstraints(AWSProperty):
     props = {
-        'MaxValue': (str, False),
-        'MinValue': (str, False),
+        'MaxValue': (basestring, False),
+        'MinValue': (basestring, False),
     }
 
 
 class StringAttributeConstraints(AWSProperty):
     props = {
-        'MaxLength': (str, False),
-        'MinLength': (str, False),
+        'MaxLength': (basestring, False),
+        'MinLength': (basestring, False),
     }
 
 
 class SchemaAttribute(AWSProperty):
     props = {
-        'AttributeDataType': (str, False),
+        'AttributeDataType': (basestring, False),
         'DeveloperOnlyAttribute': (boolean, False),
         'Mutable': (boolean, False),
-        'Name': (str, False),
+        'Name': (basestring, False),
         'NumberAttributeConstraints': (NumberAttributeConstraints, False),
         'StringAttributeConstraints': (StringAttributeConstraints, False),
         'Required': (boolean, False),
@@ -171,25 +171,25 @@ class SchemaAttribute(AWSProperty):
 
 class SmsConfiguration(AWSProperty):
     props = {
-        'ExternalId': (str, False),
-        'SnsCallerArn': (str, True),
+        'ExternalId': (basestring, False),
+        'SnsCallerArn': (basestring, True),
     }
 
 
 class UserPoolAddOns(AWSProperty):
     props = {
-        'AdvancedSecurityMode': (str, False),
+        'AdvancedSecurityMode': (basestring, False),
     }
 
 
 class VerificationMessageTemplate(AWSProperty):
     props = {
-        'DefaultEmailOption': (str, False),
-        'EmailMessage': (str, False),
-        'EmailMessageByLink': (str, False),
-        'EmailSubject': (str, False),
-        'EmailSubjectByLink': (str, False),
-        'SmsMessage': (str, False),
+        'DefaultEmailOption': (basestring, False),
+        'EmailMessage': (basestring, False),
+        'EmailMessageByLink': (basestring, False),
+        'EmailSubject': (basestring, False),
+        'EmailSubjectByLink': (basestring, False),
+        'SmsMessage': (basestring, False),
     }
 
 
@@ -198,32 +198,32 @@ class UserPool(AWSObject):
 
     props = {
         'AdminCreateUserConfig': (AdminCreateUserConfig, False),
-        'AliasAttributes': ([str], False),
-        'AutoVerifiedAttributes': ([str], False),
+        'AliasAttributes': ([basestring], False),
+        'AutoVerifiedAttributes': ([basestring], False),
         'DeviceConfiguration': (DeviceConfiguration, False),
         'EmailConfiguration': (EmailConfiguration, False),
-        'EmailVerificationMessage': (str, False),
-        'EmailVerificationSubject': (str, False),
+        'EmailVerificationMessage': (basestring, False),
+        'EmailVerificationSubject': (basestring, False),
         'LambdaConfig': (LambdaConfig, False),
-        'MfaConfiguration': (str, False),
+        'MfaConfiguration': (basestring, False),
         'Policies': (Policies, False),
         'Schema': ([SchemaAttribute], False),
-        'SmsAuthenticationMessage': (str, False),
+        'SmsAuthenticationMessage': (basestring, False),
         'SmsConfiguration': (SmsConfiguration, False),
-        'SmsVerificationMessage': (str, False),
+        'SmsVerificationMessage': (basestring, False),
         'UserPoolAddOns': (UserPoolAddOns, False),
-        'UserPoolName': (str, False),
+        'UserPoolName': (basestring, False),
         'UserPoolTags': (dict, False),
-        'UsernameAttributes': ([str], False),
+        'UsernameAttributes': ([basestring], False),
         'VerificationMessageTemplate': (VerificationMessageTemplate, False),
     }
 
 
 class AnalyticsConfiguration(AWSProperty):
     props = {
-        'ApplicationId': (str, False),
-        'ExternalId': (str, False),
-        'RoleArn': (str, False),
+        'ApplicationId': (basestring, False),
+        'ExternalId': (basestring, False),
+        'RoleArn': (basestring, False),
         'UserDataShared': (boolean, False),
     }
 
@@ -232,21 +232,21 @@ class UserPoolClient(AWSObject):
     resource_type = "AWS::Cognito::UserPoolClient"
 
     props = {
-        'AllowedOAuthFlows': ([str], False),
+        'AllowedOAuthFlows': ([basestring], False),
         'AllowedOAuthFlowsUserPoolClient': (boolean, False),
-        'AllowedOAuthScopes': ([str], False),
+        'AllowedOAuthScopes': ([basestring], False),
         'AnalyticsConfiguration': (AnalyticsConfiguration, False),
-        'CallbackURLs': ([str], False),
-        'ClientName': (str, False),
-        'DefaultRedirectURI': (str, False),
-        'ExplicitAuthFlows': ([str], False),
+        'CallbackURLs': ([basestring], False),
+        'ClientName': (basestring, False),
+        'DefaultRedirectURI': (basestring, False),
+        'ExplicitAuthFlows': ([basestring], False),
         'GenerateSecret': (boolean, False),
-        'LogoutURLs': ([str], False),
-        'ReadAttributes': ([str], False),
-        'RefreshTokenValidity': (float, False),
-        'SupportedIdentityProviders': ([str], False),
-        'UserPoolId': (str, True),
-        'WriteAttributes': ([str], False),
+        'LogoutURLs': ([basestring], False),
+        'ReadAttributes': ([basestring], False),
+        'RefreshTokenValidity': (double, False),
+        'SupportedIdentityProviders': ([basestring], False),
+        'UserPoolId': (basestring, True),
+        'WriteAttributes': ([basestring], False),
     }
 
 
@@ -254,18 +254,18 @@ class UserPoolGroup(AWSObject):
     resource_type = "AWS::Cognito::UserPoolGroup"
 
     props = {
-        'Description': (str, False),
-        'GroupName': (str, True),
+        'Description': (basestring, False),
+        'GroupName': (basestring, True),
         'Precedence': (positive_integer, False),
-        'RoleArn': (str, False),
-        'UserPoolId': (str, True),
+        'RoleArn': (basestring, False),
+        'UserPoolId': (basestring, True),
     }
 
 
 class AttributeType(AWSProperty):
     props = {
-        'Name': (str, True),
-        'Value': (str, False),
+        'Name': (basestring, True),
+        'Value': (basestring, False),
     }
 
 
@@ -273,12 +273,12 @@ class UserPoolUser(AWSObject):
     resource_type = "AWS::Cognito::UserPoolUser"
 
     props = {
-        'DesiredDeliveryMediums': ([str], False),
+        'DesiredDeliveryMediums': ([basestring], False),
         'ForceAliasCreation': (boolean, False),
         'UserAttributes': ([AttributeType], False),
-        'MessageAction': (str, False),
-        'Username': (str, False),
-        'UserPoolId': (str, True),
+        'MessageAction': (basestring, False),
+        'Username': (basestring, False),
+        'UserPoolId': (basestring, True),
         'ValidationData': ([AttributeType], False),
     }
 
@@ -287,7 +287,7 @@ class UserPoolUserToGroupAttachment(AWSObject):
     resource_type = "AWS::Cognito::UserPoolUserToGroupAttachment"
 
     props = {
-        'GroupName': (str, True),
-        'Username': (str, True),
-        'UserPoolId': (str, True),
+        'GroupName': (basestring, True),
+        'Username': (basestring, True),
+        'UserPoolId': (basestring, True),
     }
