@@ -4,7 +4,7 @@
 # See LICENSE file for full license.
 
 from . import AWSObject, AWSProperty
-from .validators import boolean
+from .validators import boolean, integer
 
 
 ONE_HOUR = "One_Hour"
@@ -139,13 +139,70 @@ class DeliveryChannel(AWSObject):
     }
 
 
+class OrganizationCustomRuleMetadata(AWSProperty):
+    props = {
+        'Description': (str, False),
+        'InputParameters': (str, False),
+        'LambdaFunctionArn': (str, True),
+        'MaximumExecutionFrequency': (str, False),
+        'OrganizationConfigRuleTriggerTypes': ([str], True),
+        'ResourceIdScope': (str, False),
+        'ResourceTypesScope': ([str], False),
+        'TagKeyScope': (str, False),
+        'TagValueScope': (str, False),
+    }
+
+
+class OrganizationManagedRuleMetadata(AWSProperty):
+    props = {
+        'Description': (str, False),
+        'InputParameters': (str, False),
+        'MaximumExecutionFrequency': (str, False),
+        'ResourceIdScope': (str, False),
+        'ResourceTypesScope': ([str], False),
+        'RuleIdentifier': (str, True),
+        'TagKeyScope': (str, False),
+        'TagValueScope': (str, False),
+    }
+
+
+class OrganizationConfigRule(AWSObject):
+    resource_type = "AWS::Config::OrganizationConfigRule"
+
+    props = {
+        'ExcludedAccounts': ([str], False),
+        'OrganizationConfigRuleName': (str, True),
+        'OrganizationCustomRuleMetadata':
+            (OrganizationCustomRuleMetadata, False),
+        'OrganizationManagedRuleMetadata':
+            (OrganizationManagedRuleMetadata, False),
+    }
+
+
+class SsmControls(AWSProperty):
+    props = {
+        'ConcurrentExecutionRatePercentage': (integer, False),
+        'ErrorPercentage': (integer, False),
+    }
+
+
+class ExecutionControls(AWSProperty):
+    props = {
+        'SsmControls': (SsmControls, False),
+    }
+
+
 class RemediationConfiguration(AWSObject):
     resource_type = "AWS::Config::RemediationConfiguration"
 
     props = {
+        'Automatic': (boolean, False),
         'ConfigRuleName': (str, True),
+        'ExecutionControls': (ExecutionControls, False),
+        'MaximumAutomaticAttempts': (integer, False),
         'Parameters': (dict, False),
         'ResourceType': (str, False),
+        'RetryAttemptSeconds': (integer, False),
         'TargetId': (str, True),
         'TargetType': (str, True),
         'TargetVersion': (str, False),
