@@ -15,17 +15,17 @@ class Cluster(AWSObject):
     resource_type = "AWS::ECS::Cluster"
 
     props = {
-        'ClusterName': (str, False),
+        'ClusterName': (basestring, False),
         'Tags': (Tags, False),
     }
 
 
 class LoadBalancer(AWSProperty):
     props = {
-        'ContainerName': (str, False),
+        'ContainerName': (basestring, False),
         'ContainerPort': (network_port, True),
-        'LoadBalancerName': (str, False),
-        'TargetGroupArn': (str, False),
+        'LoadBalancerName': (basestring, False),
+        'TargetGroupArn': (basestring, False),
     }
 
 
@@ -63,20 +63,20 @@ def scope_validator(x):
 class PlacementConstraint(AWSProperty):
     props = {
         'Type': (placement_constraint_validator, True),
-        'Expression': (str, False),
+        'Expression': (basestring, False),
     }
 
 
 class PlacementStrategy(AWSProperty):
     props = {
         'Type': (placement_strategy_validator, True),
-        'Field': (str, False),
+        'Field': (basestring, False),
     }
 
 
 class AwsvpcConfiguration(AWSProperty):
     props = {
-        'AssignPublicIp': (str, False),
+        'AssignPublicIp': (basestring, False),
         'SecurityGroups': (list, False),
         'Subnets': (list, True),
     }
@@ -98,10 +98,10 @@ def launch_type_validator(x):
 
 class ServiceRegistry(AWSProperty):
     props = {
-        'ContainerName': (str, False),
+        'ContainerName': (basestring, False),
         'ContainerPort': (integer, False),
         'Port': (integer, False),
-        'RegistryArn': (str, False),
+        'RegistryArn': (basestring, False),
     }
 
 
@@ -109,7 +109,7 @@ class Service(AWSObject):
     resource_type = "AWS::ECS::Service"
 
     props = {
-        'Cluster': (str, False),
+        'Cluster': (basestring, False),
         'DeploymentConfiguration': (DeploymentConfiguration, False),
         'DesiredCount': (positive_integer, False),
         'EnableECSManagedTags': (boolean, False),
@@ -117,30 +117,30 @@ class Service(AWSObject):
         'LaunchType': (launch_type_validator, False),
         'LoadBalancers': ([LoadBalancer], False),
         'NetworkConfiguration': (NetworkConfiguration, False),
-        'Role': (str, False),
+        'Role': (basestring, False),
         'PlacementConstraints': ([PlacementConstraint], False),
         'PlacementStrategies': ([PlacementStrategy], False),
-        'PlatformVersion': (str, False),
-        'PropagateTags': (str, False),
-        'SchedulingStrategy': (str, False),
-        'ServiceName': (str, False),
+        'PlatformVersion': (basestring, False),
+        'PropagateTags': (basestring, False),
+        'SchedulingStrategy': (basestring, False),
+        'ServiceName': (basestring, False),
         'ServiceRegistries': ([ServiceRegistry], False),
         'Tags': (Tags, False),
-        'TaskDefinition': (str, True),
+        'TaskDefinition': (basestring, True),
     }
 
 
 class Environment(AWSProperty):
     props = {
-        'Name': (str, True),
-        'Value': (str, True),
+        'Name': (basestring, True),
+        'Value': (basestring, True),
     }
 
 
 class MountPoint(AWSProperty):
     props = {
-        'ContainerPath': (str, True),
-        'SourceVolume': (str, True),
+        'ContainerPath': (basestring, True),
+        'SourceVolume': (basestring, True),
         'ReadOnly': (boolean, False),
     }
 
@@ -149,35 +149,35 @@ class PortMapping(AWSProperty):
     props = {
         'ContainerPort': (network_port, True),
         'HostPort': (network_port, False),
-        'Protocol': (str, False),
+        'Protocol': (basestring, False),
     }
 
 
 class VolumesFrom(AWSProperty):
     props = {
-        'SourceContainer': (str, True),
+        'SourceContainer': (basestring, True),
         'ReadOnly': (boolean, False),
     }
 
 
 class HostEntry(AWSProperty):
     props = {
-        'Hostname': (str, True),
-        'IpAddress': (str, True),
+        'Hostname': (basestring, True),
+        'IpAddress': (basestring, True),
     }
 
 
 class Device(AWSProperty):
     props = {
-        'ContainerPath': (str, False),
-        'HostPath': (str, False),
-        'Permissions': ([str], False),
+        'ContainerPath': (basestring, False),
+        'HostPath': (basestring, False),
+        'Permissions': ([basestring], False),
     }
 
 
 class HealthCheck(AWSProperty):
     props = {
-        'Command': ([str], True),
+        'Command': ([basestring], True),
         'Interval': (integer, False),
         'Retries': (integer, False),
         'StartPeriod': (integer, False),
@@ -187,15 +187,15 @@ class HealthCheck(AWSProperty):
 
 class KernelCapabilities(AWSProperty):
     props = {
-        'Add': ([str], False),
-        'Drop': ([str], False),
+        'Add': ([basestring], False),
+        'Drop': ([basestring], False),
     }
 
 
 class Tmpfs(AWSProperty):
     props = {
-        'ContainerPath': (str, False),
-        'MountOptions': ([str], False),
+        'ContainerPath': (basestring, False),
+        'MountOptions': ([basestring], False),
         'Size': (integer, False),
     }
 
@@ -210,97 +210,108 @@ class LinuxParameters(AWSProperty):
     }
 
 
+class Secret(AWSProperty):
+    props = {
+        'Name': (basestring, True),
+        'ValueFrom': (basestring, True),
+    }
+
+
 class LogConfiguration(AWSProperty):
     props = {
-        'LogDriver': (str, True),
+        'LogDriver': (basestring, True),
         'Options': (dict, False),
+        'SecretOptions': ([Secret], False),
     }
 
 
 class RepositoryCredentials(AWSProperty):
     props = {
-        'CredentialsParameter': (str, False)
+        'CredentialsParameter': (basestring, False)
     }
 
 
 class ResourceRequirement(AWSProperty):
     props = {
-        'Type': (str, True),
-        'Value': (str, True),
+        'Type': (basestring, True),
+        'Value': (basestring, True),
     }
 
 
-class Secret(AWSProperty):
+class SystemControl(AWSProperty):
     props = {
-        'Name': (str, True),
-        'ValueFrom': (str, True),
+        'Namespace': (basestring, True),
+        'Value': (basestring, True),
     }
 
 
 class Ulimit(AWSProperty):
     props = {
         'HardLimit': (integer, True),
-        'Name': (str, True),
+        'Name': (basestring, True),
         'SoftLimit': (integer, True),
     }
 
 
 class ContainerDependency(AWSProperty):
     props = {
-        'Condition': (str, True),
-        'ContainerName': (str, True)
+        'Condition': (basestring, True),
+        'ContainerName': (basestring, True)
     }
 
 
 class ContainerDefinition(AWSProperty):
     props = {
-        'Command': ([str], False),
+        'Command': ([basestring], False),
         'Cpu': (positive_integer, False),
         'DependsOn': ([ContainerDependency], False),
         'DisableNetworking': (boolean, False),
-        'DnsSearchDomains': ([str], False),
-        'DnsServers': ([str], False),
+        'DnsSearchDomains': ([basestring], False),
+        'DnsServers': ([basestring], False),
         'DockerLabels': (dict, False),
-        'DockerSecurityOptions': ([str], False),
-        'EntryPoint': ([str], False),
+        'DockerSecurityOptions': ([basestring], False),
+        'EntryPoint': ([basestring], False),
         'Environment': ([Environment], False),
         'Essential': (boolean, False),
         'ExtraHosts': ([HostEntry], False),
         'HealthCheck': (HealthCheck, False),
-        'Hostname': (str, False),
-        'Image': (str, False),
-        'Links': ([str], False),
+        'Hostname': (basestring, False),
+        'Image': (basestring, False),
+        'Interactive': (boolean, False),
+        'Links': ([basestring], False),
         'LinuxParameters': (LinuxParameters, False),
         'LogConfiguration': (LogConfiguration, False),
         'Memory': (positive_integer, False),
         'MemoryReservation': (positive_integer, False),
         'MountPoints': ([MountPoint], False),
-        'Name': (str, False),
+        'Name': (basestring, False),
         'PortMappings': ([PortMapping], False),
         'Privileged': (boolean, False),
+        'PseudoTerminal': (boolean, False),
         'ReadonlyRootFilesystem': (boolean, False),
         'RepositoryCredentials': (RepositoryCredentials, False),
         'ResourceRequirements': ([ResourceRequirement], False),
         'Secrets': ([Secret], False),
         'StartTimeout': (integer, False),
         'StopTimeout': (integer, False),
+        'SystemControls': ([SystemControl], False),
         'Ulimits': ([Ulimit], False),
-        'User': (str, False),
+        'User': (basestring, False),
         'VolumesFrom': ([VolumesFrom], False),
-        'WorkingDirectory': (str, False),
+        'WorkingDirectory': (basestring, False),
     }
 
 
 class Host(AWSProperty):
     props = {
-        'SourcePath': (str, False),
+        'SourcePath': (basestring, False),
     }
 
 
 class DockerVolumeConfiguration(AWSProperty):
     props = {
         'Autoprovision': (boolean, False),
-        'Driver': (str, False),
+        'Driver': (basestring, False),
         'DriverOpts': (dict, False),
         'Labels': (dict, False),
         'Scope': (scope_validator, False)
@@ -310,14 +321,14 @@ class DockerVolumeConfiguration(AWSProperty):
 class Volume(AWSProperty):
     props = {
         'DockerVolumeConfiguration': (DockerVolumeConfiguration, False),
-        'Name': (str, True),
+        'Name': (basestring, True),
         'Host': (Host, False),
     }
 
 
 class ProxyConfiguration(AWSProperty):
     props = {
-        'ContainerName': (str, True),
+        'ContainerName': (basestring, True),
         'ProxyConfigurationProperties': (list, False),
         'Type': (ecs_proxy_type, False)
     }
@@ -328,15 +339,17 @@ class TaskDefinition(AWSObject):
 
     props = {
         'ContainerDefinitions': ([ContainerDefinition], False),
-        'Cpu': (str, False),
-        'ExecutionRoleArn': (str, False),
-        'Family': (str, False),
-        'Memory': (str, False),
-        'NetworkMode': (str, False),
+        'Cpu': (basestring, False),
+        'ExecutionRoleArn': (basestring, False),
+        'Family': (basestring, False),
+        'IpcMode': (basestring, False),
+        'Memory': (basestring, False),
+        'NetworkMode': (basestring, False),
+        'PidMode': (basestring, False),
         'PlacementConstraints': ([PlacementConstraint], False),
-        'RequiresCompatibilities': ([str], False),
+        'ProxyConfiguration': (ProxyConfiguration, False),
+        'RequiresCompatibilities': ([basestring], False),
         'Tags': (Tags, False),
-        'TaskRoleArn': (str, False),
+        'TaskRoleArn': (basestring, False),
         'Volumes': ([Volume], False),
-        'ProxyConfiguration': (ProxyConfiguration, False)
     }
