@@ -24,7 +24,7 @@ def provisioned_throughput_validator(throughput):
 
 class LifecyclePolicy(AWSProperty):
     props = {
-        'TransitionToIA': (str, True),
+        'TransitionToIA': (basestring, True),
     }
 
 
@@ -34,9 +34,9 @@ class FileSystem(AWSObject):
     props = {
         'Encrypted': (boolean, False),
         'FileSystemTags': (Tags, False),
-        'KmsKeyId': (str, False),
+        'KmsKeyId': (basestring, False),
         'LifecyclePolicies': ([LifecyclePolicy], False),
-        'PerformanceMode': (str, False),
+        'PerformanceMode': (basestring, False),
         'ProvisionedThroughputInMibps': (float, False),
         'ThroughputMode': (throughput_mode_validator, False),
     }
@@ -46,8 +46,8 @@ class MountTarget(AWSObject):
     resource_type = "AWS::EFS::MountTarget"
 
     props = {
-        'FileSystemId': (str, True),
-        'IpAddress': (str, False),
-        'SecurityGroups': ([str], True),
-        'SubnetId': (str, True),
+        'FileSystemId': (basestring, True),
+        'IpAddress': (basestring, False),
+        'SecurityGroups': ([basestring], True),
+        'SubnetId': (basestring, True),
     }
