@@ -11,36 +11,36 @@ from .validators import integer, integer_range, positive_integer
 class CsvClassifier(AWSProperty):
     props = {
         'AllowSingleColumn': (boolean, False),
-        'ContainsHeader': (str, False),
-        'Delimiter': (str, False),
+        'ContainsHeader': (basestring, False),
+        'Delimiter': (basestring, False),
         'DisableValueTrimming': (boolean, False),
-        'Header': ([str], False),
-        'Name': (str, False),
-        'QuoteSymbol': (str, False),
+        'Header': ([basestring], False),
+        'Name': (basestring, False),
+        'QuoteSymbol': (basestring, False),
     }
 
 
 class GrokClassifier(AWSProperty):
     props = {
-        'Classification': (str, True),
-        'CustomPatterns': (str, False),
-        'GrokPattern': (str, True),
-        'Name': (str, False),
+        'Classification': (basestring, True),
+        'CustomPatterns': (basestring, False),
+        'GrokPattern': (basestring, True),
+        'Name': (basestring, False),
     }
 
 
 class JsonClassifier(AWSProperty):
     props = {
-        'JsonPath': (str, True),
-        'Name': (str, False),
+        'JsonPath': (basestring, True),
+        'Name': (basestring, False),
     }
 
 
 class XMLClassifier(AWSProperty):
     props = {
-        'Classification': (str, True),
-        'Name': (str, False),
-        'RowTag': (str, True),
+        'Classification': (basestring, True),
+        'Name': (basestring, False),
+        'RowTag': (basestring, True),
     }
 
 
@@ -57,9 +57,9 @@ class Classifier(AWSObject):
 
 class PhysicalConnectionRequirements(AWSProperty):
     props = {
-        'AvailabilityZone': (str, False),
-        'SecurityGroupIdList': ([str], False),
-        'SubnetId': (str, False),
+        'AvailabilityZone': (basestring, False),
+        'SecurityGroupIdList': ([basestring], False),
+        'SubnetId': (basestring, False),
     }
 
 
@@ -77,9 +77,9 @@ class ConnectionInput(AWSProperty):
     props = {
         'ConnectionProperties': (dict, True),
         'ConnectionType': (connection_type_validator, True),
-        'Description': (str, False),
-        'MatchCriteria': ([str], False),
-        'Name': (str, False),
+        'Description': (basestring, False),
+        'MatchCriteria': ([basestring], False),
+        'Name': (basestring, False),
         'PhysicalConnectionRequirements':
             (PhysicalConnectionRequirements, False),
     }
@@ -89,14 +89,14 @@ class Connection(AWSObject):
     resource_type = "AWS::Glue::Connection"
 
     props = {
-        'CatalogId': (str, True),
+        'CatalogId': (basestring, True),
         'ConnectionInput': (ConnectionInput, True),
     }
 
 
 class Schedule(AWSProperty):
     props = {
-        'ScheduleExpression': (str, False),
+        'ScheduleExpression': (basestring, False),
     }
 
 
@@ -130,16 +130,16 @@ class SchemaChangePolicy(AWSProperty):
 
 class JdbcTarget(AWSProperty):
     props = {
-        'ConnectionName': (str, False),
-        'Exclusions': ([str], False),
-        'Path': (str, False),
+        'ConnectionName': (basestring, False),
+        'Exclusions': ([basestring], False),
+        'Path': (basestring, False),
     }
 
 
 class S3Target(AWSProperty):
     props = {
-        'Exclusions': ([str], False),
-        'Path': (str, False),
+        'Exclusions': ([basestring], False),
+        'Path': (basestring, False),
     }
 
 
@@ -154,16 +154,16 @@ class Crawler(AWSObject):
     resource_type = "AWS::Glue::Crawler"
 
     props = {
-        'Classifiers': ([str], False),
-        'Configuration': (str, False),
-        'CrawlerSecurityConfiguration': (str, False),
-        'DatabaseName': (str, True),
-        'Description': (str, False),
-        'Name': (str, False),
-        'Role': (str, True),
+        'Classifiers': ([basestring], False),
+        'Configuration': (basestring, False),
+        'CrawlerSecurityConfiguration': (basestring, False),
+        'DatabaseName': (basestring, True),
+        'Description': (basestring, False),
+        'Name': (basestring, False),
+        'Role': (basestring, True),
         'Schedule': (Schedule, False),
         'SchemaChangePolicy': (SchemaChangePolicy, False),
-        'TablePrefix': (str, False),
+        'TablePrefix': (basestring, False),
         'Tags': (dict, False),
         'Targets': (Targets, True),
     }
@@ -171,15 +171,15 @@ class Crawler(AWSObject):
 
 class ConnectionPasswordEncryption(AWSProperty):
     props = {
-        'KmsKeyId': (str, False),
+        'KmsKeyId': (basestring, False),
         'ReturnConnectionPasswordEncrypted': (boolean, False),
     }
 
 
 class EncryptionAtRest(AWSProperty):
     props = {
-        'CatalogEncryptionMode': (str, False),
-        'SseAwsKmsKeyId': (str, False),
+        'CatalogEncryptionMode': (basestring, False),
+        'SseAwsKmsKeyId': (basestring, False),
     }
 
 
@@ -195,7 +195,7 @@ class DataCatalogEncryptionSettings(AWSObject):
     resource_type = "AWS::Glue::DataCatalogEncryptionSettings"
 
     props = {
-        'CatalogId': (str, True),
+        'CatalogId': (basestring, True),
         'DataCatalogEncryptionSettings':
             (DataCatalogEncryptionSettingsProperty, True),
     }
@@ -203,9 +203,9 @@ class DataCatalogEncryptionSettings(AWSObject):
 
 class DatabaseInput(AWSProperty):
     props = {
-        'Description': (str, False),
-        'LocationUri': (str, False),
-        'Name': (str, False),
+        'Description': (basestring, False),
+        'LocationUri': (basestring, False),
+        'Name': (basestring, False),
         'Parameters': (dict, False),
     }
 
@@ -214,7 +214,7 @@ class Database(AWSObject):
     resource_type = "AWS::Glue::Database"
 
     props = {
-        'CatalogId': (str, True),
+        'CatalogId': (basestring, True),
         'DatabaseInput': (DatabaseInput, True),
     }
 
@@ -223,22 +223,26 @@ class DevEndpoint(AWSObject):
     resource_type = "AWS::Glue::DevEndpoint"
 
     props = {
-        'EndpointName': (str, False),
-        'ExtraJarsS3Path': (str, False),
-        'ExtraPythonLibsS3Path': (str, False),
-        'NumberOfNodes': (positive_integer, False),
-        'PublicKey': (str, True),
-        'RoleArn': (str, True),
-        'SecurityConfiguration': (str, False),
-        'SecurityGroupIds': ([str], False),
-        'SubnetId': (str, False),
+        'Arguments': (dict, False),
+        'EndpointName': (basestring, False),
+        'ExtraJarsS3Path': (basestring, False),
+        'ExtraPythonLibsS3Path': (basestring, False),
+        'GlueVersion': (basestring, False),
+        'NumberOfNodes': (integer, False),
+        'NumberOfWorkers': (integer, False),
+        'PublicKey': (basestring, False),
+        'RoleArn': (basestring, True),
+        'SecurityConfiguration': (basestring, False),
+        'SecurityGroupIds': ([basestring], False),
+        'SubnetId': (basestring, False),
         'Tags': (dict, False),
+        'WorkerType': (basestring, False),
     }
 
 
 class ConnectionsList(AWSProperty):
     props = {
-        'Connections': ([str], False),
+        'Connections': ([basestring], False),
     }
 
 
@@ -250,8 +254,15 @@ class ExecutionProperty(AWSProperty):
 
 class JobCommand(AWSProperty):
     props = {
-        'Name': (str, False),
-        'ScriptLocation': (str, False),
+        'Name': (basestring, False),
+        'PythonVersion': (basestring, False),
+        'ScriptLocation': (basestring, False),
+    }
+
+
+class NotificationProperty(AWSProperty):
+    props = {
+        'NotifyDelayAfter': (integer, False),
     }
 
 
@@ -263,27 +274,29 @@ class Job(AWSObject):
         'Command': (JobCommand, True),
         'Connections': (ConnectionsList, False),
         'DefaultArguments': (dict, False),
-        'Description': (str, False),
+        'Description': (basestring, False),
         'ExecutionProperty': (ExecutionProperty, False),
-        'GlueVersion': (str, False),
-        'LogUri': (str, False),
+        'GlueVersion': (basestring, False),
+        'LogUri': (basestring, False),
         'MaxCapacity': (double, False),
         'MaxRetries': (double, False),
-        'Name': (str, False),
+        'Name': (basestring, False),
+        'NotificationProperty': (NotificationProperty, False),
         'NumberOfWorkers': (integer, False),
-        'Role': (str, True),
-        'SecurityConfiguration': (str, False),
+        'Role': (basestring, True),
+        'SecurityConfiguration': (basestring, False),
         'Tags': (dict, False),
-        'WorkerType': (str, False),
+        'Timeout': (integer, False),
+        'WorkerType': (basestring, False),
     }
 
 
 class GlueTables(AWSProperty):
     props = {
-        'CatalogId': (str, False),
-        'ConnectionName': (str, False),
-        'DatabaseName': (str, True),
-        'TableName': (str, True),
+        'CatalogId': (basestring, False),
+        'ConnectionName': (basestring, False),
+        'DatabaseName': (basestring, True),
+        'TableName': (basestring, True),
     }
 
 
@@ -298,14 +311,14 @@ class FindMatchesParameters(AWSProperty):
         'AccuracyCostTradeoff': (float, False),
         'EnforceProvidedLabels': (boolean, False),
         'PrecisionRecallTradeoff': (float, False),
-        'PrimaryKeyColumnName': (str, True),
+        'PrimaryKeyColumnName': (basestring, True),
     }
 
 
 class TransformParameters(AWSProperty):
     props = {
         'FindMatchesParameters': (FindMatchesParameters, False),
-        'TransformType': (str, True),
+        'TransformType': (basestring, True),
     }
 
 
@@ -313,59 +326,59 @@ class MLTransform(AWSObject):
     resource_type = "AWS::Glue::MLTransform"
 
     props = {
-        'Description': (str, False),
+        'Description': (basestring, False),
         'InputRecordTables': (InputRecordTables, True),
         'MaxCapacity': (float, False),
         'MaxRetries': (integer, False),
-        'Name': (str, False),
+        'Name': (basestring, False),
         'NumberOfWorkers': (integer, False),
-        'Role': (str, True),
+        'Role': (basestring, True),
         'Timeout': (integer, False),
         'TransformParameters': (TransformParameters, True),
-        'WorkerType': (str, False),
+        'WorkerType': (basestring, False),
     }
 
 
 class Column(AWSProperty):
     props = {
-        'Comment': (str, False),
-        'Name': (str, True),
-        'Type': (str, False),
+        'Comment': (basestring, False),
+        'Name': (basestring, True),
+        'Type': (basestring, False),
     }
 
 
 class Order(AWSProperty):
     props = {
-        'Column': (str, True),
+        'Column': (basestring, True),
         'SortOrder': (integer_range(0, 1), False),
     }
 
 
 class SerdeInfo(AWSProperty):
     props = {
-        'Name': (str, False),
+        'Name': (basestring, False),
         'Parameters': (dict, False),
-        'SerializationLibrary': (str, False),
+        'SerializationLibrary': (basestring, False),
     }
 
 
 class SkewedInfo(AWSProperty):
     props = {
-        'SkewedColumnNames': ([str], False),
-        'SkewedColumnValues': ([str], False),
+        'SkewedColumnNames': ([basestring], False),
+        'SkewedColumnValues': ([basestring], False),
         'SkewedColumnValueLocationMaps': (dict, False),
     }
 
 
 class StorageDescriptor(AWSProperty):
     props = {
-        'BucketColumns': ([str], False),
+        'BucketColumns': ([basestring], False),
         'Columns': ([Column], False),
         'Compressed': (boolean, False),
-        'InputFormat': (str, False),
-        'Location': (str, False),
+        'InputFormat': (basestring, False),
+        'Location': (basestring, False),
         'NumberOfBuckets': (positive_integer, False),
-        'OutputFormat': (str, False),
+        'OutputFormat': (basestring, False),
         'Parameters': (dict, False),
         'SerdeInfo': (SerdeInfo, False),
         'SkewedInfo': (SkewedInfo, False),
@@ -378,7 +391,7 @@ class PartitionInput(AWSProperty):
     props = {
         'Parameters': (dict, False),
         'StorageDescriptor': (StorageDescriptor, False),
-        'Values': ([str], True),
+        'Values': ([basestring], True),
     }
 
 
@@ -386,24 +399,24 @@ class Partition(AWSObject):
     resource_type = "AWS::Glue::Partition"
 
     props = {
-        'CatalogId': (str, True),
-        'DatabaseName': (str, True),
+        'CatalogId': (basestring, True),
+        'DatabaseName': (basestring, True),
         'PartitionInput': (PartitionInput, True),
-        'TableName': (str, True),
+        'TableName': (basestring, True),
     }
 
 
 class CloudWatchEncryption(AWSProperty):
     props = {
-        'CloudWatchEncryptionMode': (str, False),
-        'KmsKeyArn': (str, False),
+        'CloudWatchEncryptionMode': (basestring, False),
+        'KmsKeyArn': (basestring, False),
     }
 
 
 class JobBookmarksEncryption(AWSProperty):
     props = {
-        'JobBookmarksEncryptionMode': (str, False),
-        'KmsKeyArn': (str, False),
+        'JobBookmarksEncryptionMode': (basestring, False),
+        'KmsKeyArn': (basestring, False),
     }
 
 
@@ -425,7 +438,7 @@ class SecurityConfiguration(AWSObject):
 
     props = {
         'EncryptionConfiguration': (EncryptionConfiguration, True),
-        'Name': (str, True),
+        'Name': (basestring, True),
     }
 
 
@@ -441,16 +454,16 @@ def table_type_validator(type):
 
 class TableInput(AWSProperty):
     props = {
-        'Description': (str, False),
-        'Name': (str, False),
-        'Owner': (str, False),
+        'Description': (basestring, False),
+        'Name': (basestring, False),
+        'Owner': (basestring, False),
         'Parameters': (dict, False),
         'PartitionKeys': ([Column], False),
         'Retention': (positive_integer, False),
         'StorageDescriptor': (StorageDescriptor, False),
         'TableType': (table_type_validator, False),
-        'ViewExpandedText': (str, False),
-        'ViewOriginalText': (str, False),
+        'ViewExpandedText': (basestring, False),
+        'ViewOriginalText': (basestring, False),
     }
 
 
@@ -458,8 +471,8 @@ class Table(AWSObject):
     resource_type = "AWS::Glue::Table"
 
     props = {
-        'CatalogId': (str, True),
-        'DatabaseName': (str, True),
+        'CatalogId': (basestring, True),
+        'DatabaseName': (basestring, True),
         'TableInput': (TableInput, True),
     }
 
@@ -467,23 +480,23 @@ class Table(AWSObject):
 class Action(AWSProperty):
     props = {
         'Arguments': (dict, False),
-        'JobName': (str, False),
-        'SecurityConfiguration': (str, False),
+        'JobName': (basestring, False),
+        'SecurityConfiguration': (basestring, False),
     }
 
 
 class Condition(AWSProperty):
     props = {
-        'JobName': (str, False),
-        'LogicalOperator': (str, False),
-        'State': (str, False),
+        'JobName': (basestring, False),
+        'LogicalOperator': (basestring, False),
+        'State': (basestring, False),
     }
 
 
 class Predicate(AWSProperty):
     props = {
         'Conditions': ([Condition], False),
-        'Logical': (str, False),
+        'Logical': (basestring, False),
     }
 
 
@@ -503,10 +516,23 @@ class Trigger(AWSObject):
 
     props = {
         'Actions': ([Action], True),
-        'Description': (str, False),
-        'Name': (str, False),
+        'Description': (basestring, False),
+        'Name': (basestring, False),
         'Predicate': (Predicate, False),
-        'Schedule': (str, False),
+        'Schedule': (basestring, False),
+        'StartOnCreation': (boolean, False),
+        'Tags': (dict, False),
+        'Type': (basestring, True),
+        'WorkflowName': (basestring, False),
+    }
+
+
+class Workflow(AWSObject):
+    resource_type = "AWS::Glue::Workflow"
+
+    props = {
+        'DefaultRunProperties': (dict, False),
+        'Description': (basestring, False),
+        'Name': (basestring, False),
         'Tags': (dict, False),
-        'Type': (trigger_type_validator, True),
     }
